'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var ExtractTextPlugin = _interopDefault(require('extract-text-webpack-plugin'));

var HandleCSSLoader = function HandleCSSLoader(ref) {
  if ( ref === void 0 ) ref = {};
  var fallbackLoader = ref.fallbackLoader; if ( fallbackLoader === void 0 ) fallbackLoader = 'style-loader';
  var cssLoader = ref.cssLoader; if ( cssLoader === void 0 ) cssLoader = 'css-loader';
  var postcss = ref.postcss;
  var sourceMap = ref.sourceMap;
  var extract = ref.extract;
  var minimize = ref.minimize;
  var cssModules = ref.cssModules;

  this.fallbackLoader = fallbackLoader;
  this.cssLoader = cssLoader;
  this.postcssOptions = postcss;
  this.sourceMap = sourceMap;
  this.extract = extract;
  this.minimize = minimize;
  this.cssModules = cssModules;
};

HandleCSSLoader.prototype.getLoader = function getLoader (test, loader, options) {
    if ( options === void 0 ) options = {};

  var cssLoaderOptions = {
    autoprefixer: false,
    sourceMap: this.sourceMap,
    minimize: this.minimize
  };

  if (this.cssModules) {
    cssLoaderOptions.modules = true;
    cssLoaderOptions.importLoaders = 1;
    cssLoaderOptions.localIdentName = '[name]_[local]__[hash:base64:5]';
  }

  if (loader === 'css-loader') {
    Object.assign(cssLoaderOptions, options);
  }

  var use = [{
    loader: this.cssLoader,
    options: cssLoaderOptions
  }];

  if (loader !== 'postcss-loader' && this.postcssOptions !== false) {
    var postcssOptions = {
      sourceMap: this.sourceMap
    };

    if (Array.isArray(this.postcssOptions)) {
      postcssOptions.plugins = this.postcssOptions;
    } else if (typeof this.postcssOptions === 'object') {
      Object.assign(postcssOptions, this.postcssOptions);
    }

    use.push({
      loader: 'postcss-loader',
      options: postcssOptions
    });
  }

  if (loader && loader !== 'css-loader') {
    use.push({
      loader: loader,
      options: Object.assign({}, options,
        {sourceMap: this.sourceMap})
    });
  }

  return {
    test: test,
    use: this.extract ? ExtractTextPlugin.extract({
      use: use,
      fallback: this.fallbackLoader
    }) : [{
      loader: this.fallbackLoader,
      options: {
        sourceMap: this.sourceMap
      }
    } ].concat( use)
  }
};

HandleCSSLoader.prototype.css = function css (options) {
  return this.getLoader(/\.css$/, 'css-loader', options)
};

HandleCSSLoader.prototype.sass = function sass (options) {
    if ( options === void 0 ) options = {};

  return this.getLoader(/\.sass$/, 'sass-loader', Object.assign({}, {indentedSyntax: true},
    options))
};

HandleCSSLoader.prototype.scss = function scss (options) {
  return this.getLoader(/\.scss$/, 'sass-loader', options)
};

HandleCSSLoader.prototype.less = function less (options) {
  return this.getLoader(/\.less$/, 'less-loader', options)
};

HandleCSSLoader.prototype.stylus = function stylus (options) {
  return this.getLoader(/\.stylus$/, 'stylus-loader', options)
};

HandleCSSLoader.prototype.styl = function styl (options) {
  return this.getLoader(/\.styl$/, 'stylus-loader', options)
};

HandleCSSLoader.prototype.vue = function vue (options) {
    var this$1 = this;
    if ( options === void 0 ) options = {};

  this.postcssOptions = false;
  this.cssModules = false;
  var loaders = {};
  for (var i = 0, list = ['css', 'sass', 'scss', 'less', 'stylus', 'styl']; i < list.length; i += 1) {
    var lang = list[i];

      loaders[lang] = this$1[lang](options[lang]).use;
  }
  return loaders
};

module.exports = HandleCSSLoader;
